@@ -1,7 +1,5 @@
-from oauthlib.oauth2 import BackendApplicationClient
-from requests_oauthlib import OAuth2Session
-from functools import lru_cache
-from requests import auth
+from typing import Optional, Mapping
+from identitylib.api_client import IdentityAPIClient
 
 
 class NoSuchPhotoException(Exception):
@@ -9,7 +7,7 @@ class NoSuchPhotoException(Exception):
         super().__init__('No photo found for query criteria')
 
 
-class PhotoClient:
+class PhotoClient (IdentityAPIClient):
     """
     A client which allows information to be fetched from the University Photo API.
 
@@ -20,30 +18,13 @@ class PhotoClient:
         client_id: str,
         client_secret: str,
         base_url: str = 'https://api.apps.cam.ac.uk/photo/v1beta1/',
-        token_url: str = 'https://api.apps.cam.ac.uk/oauth/client_credential/accesstoken'
+        token_url: str = 'https://api.apps.cam.ac.uk/oauth/client_credential/accesstoken',
+        config: Optional[Mapping] = {},
     ):
-        self.client_id = client_id
-        self.client_secret = client_secret
 
-        self.base_url = base_url.rstrip('/')
-        self.token_url = token_url
-
-    @property
-    @lru_cache()
-    def session(self):
-        """
-        Lazy-init a OAuth2-wrapped session and fetch a token before it's used.
-
-        """
-
-        client = BackendApplicationClient(client_id=self.client_id)
-        session = OAuth2Session(client=client)
-
-        session.fetch_token(
-            token_url=self.token_url,
-            auth=auth.HTTPBasicAuth(self.client_id, self.client_secret)
+        super(PhotoClient, self).__init__(
+            client_id, client_secret, base_url, token_url, config
         )
-        return session
 
     def get_transient_image_url(self, photo_id: str):
         """
